#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# Authors:  Fred Senekal (FS)
# Contact:  fred@silicogenesis.com
# License:  GPLv3

"""
Implements class `VDWRadius` to provide van der Waals radii for atoms.
"""


class VDWRadius:
    # Values below need to be checked
    # VDW_RADIUS = {
    #     "H": 1.20,
    #     "HE": 1.40,
    #     "LI": 1.82,
    #     "BE": 1.53,
    #     "B": 1.92,
    #     "C": 1.70,
    #     "N": 1.55,
    #     "O": 1.52,
    #     "F": 1.47,
    #     "NE": 1.54,
    #     "NA": 2.27,
    #     "MG": 1.73,
    #     "AL": 1.84,
    #     "SI": 2.10,
    #     "P": 1.80,
    #     "S": 1.80,
    #     "CL": 1.75,
    #     "AR": 1.88,
    #     "K": 2.75,
    #     "CA": 2.31,
    #     "SC": 2.15,
    #     "TI": 2.11,
    #     "V": 2.07,
    #     "CR": 2.06,
    #     "MN": 2.05,
    #     "FE": 2.04,
    #     "CO": 2.00,
    #     "NI": 1.97,
    #     "CU": 1.96,
    #     "ZN": 2.01,
    #     "GA": 1.87,
    #     "GE": 2.11,
    #     "AS": 1.85,
    #     "SE": 1.90,
    #     "BR": 1.83,
    #     "KR": 2.02,
    #     "RB": 3.03,
    #     "SR": 2.49,
    #     "Y": 2.32,
    #     "ZR": 2.23,
    #     "NB": 2.18,
    #     "MO": 2.17,
    #     "TC": 2.16,
    #     "RU": 2.13,
    #     "RH": 2.10,
    #     "PD": 2.10,
    #     "AG": 2.11,
    #     "CD": 2.18,
    #     "IN": 1.93,
    #     "SN": 2.17,
    #     "SB": 2.06,
    #     "TE": 2.06,
    #     "I": 1.98,
    #     "XE": 2.16,
    #     "CS": 3.43,
    #     "BA": 2.68,
    #     "LA": 2.56,
    #     "CE": 2.54,
    #     "PR": 2.67,
    #     "ND": 2.55,
    #     "PM": 2.53,
    #     "SM": 2.52,
    #     "EU": 2.52,
    #     "GD": 2.52,
    #     "TB": 2.52,
    #     "DY": 2.50,
    #     "HO": 2.74,
    #     "ER": 2.56,
    #     "TM": 2.54,
    #     "YB": 2.74,
    #     "LU": 2.56,
    #     "HF": 2.51,
    #     "TA": 2.42,
    #     "W": 2.36,
    #     "RE": 2.31,
    #     "OS": 2.28,
    #     "IR": 2.26,
    #     "PT": 2.22,
    #     "AU": 2.22,
    #     "HG": 2.22,
    #     "TL": 1.96,
    #     "PB": 2.02,
    #     "BI": 2.07,
    #     "PO": 1.97,
    #     "AT": 2.02,
    #     "RN": 2.20,
    #     "FR": 3.48,
    #     "RA": 2.83,
    #     "AC": 2.47,
    #     "TH": 2.45,
    #     "PA": 2.43,
    #     "U": 2.41,
    #     "NP": 2.39,
    #     "PU": 2.43,
    #     "AM": 2.44,
    #     "CM": 2.45,
    #     "BK": 2.44,
    #     "CF": 2.45,
    #     "ES": 2.45,
    #     "FM": 2.45,
    #     "MD": 2.46,
    #     "NO": 2.46,
    #     "LR": 2.46,
    #     "RF": 2.46,
    #     "DB": 2.46,
    #     "SG": 2.46,
    #     "BH": 2.46,
    #     "HS": 2.46,
    #     "MT": 2.46,
    #     "DS": 2.46,
    #     "RG": 2.46,
    #     "CN": 2.46,
    #     "NH": 2.46,
    #     "FL": 2.46,
    #     "MC": 2.46,
    #     "LV": 2.46,
    #     "TS": 2.46,
    #     "OG": 2.46
    # }

    VDW_RADIUS = {
        "H": 1.20,
        "C": 1.70,
        "N": 1.55,
        "O": 1.52,
        "P": 1.80,
        "S": 1.80,
        "F": 1.47,
        "CL": 1.75,
        "BR": 1.83,
        "I": 1.98,
        "SE": 1.90
    }

    # Values from
    # Shrake, A., & Rupley, J. A. (1973). Environment and exposure to solvent of protein atoms.
    # Lysozyme and insulin. Journal of Molecular Biology, 79(2), 351–371.
    # https://doi.org/10.1016/0022-2836(73)90011-9
    SURFACE_RADIUS = {
        "H": 1.20,
        "C": 1.70,
        "N": 1.55,
        "O": 1.52,
        "P": 1.80,
        "S": 1.80,
        "F": 1.47,
        "CL": 1.75,
        "BR": 1.83,
        "I": 1.98,
        "SE": 1.90
    }
